import 'dart:convert';
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/widgets.dart';
import 'package:permission_handler/permission_handler.dart';
import 'package:share_apps/model/user_bean.dart';
import 'package:share_apps/screens/contact_selection.dart';
import 'package:share_apps/utils/common_utils.dart';
import 'package:share_apps/utils/string_utils.dart';
import 'package:share_apps/widgets/widgets_importer.dart';

bool isLoading = false;
UserBean userBean;

class HomeScreen extends StatefulWidget {
  HomeScreen(UserBean bean) {
    userBean = bean;
  }

  @override
  _HomeScreenState createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen> {
  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: Scaffold(
        backgroundColor: Colors.white,
        body: Material(
          color: Colors.white,
          child: Stack(
            children: [
              SingleChildScrollView(
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    Align(
                      alignment: Alignment.centerLeft,
                      child: InkWell(
                        onTap: () {
                          Navigator.pop(context);
                        },
                        child: Padding(
                          padding: const EdgeInsets.all(20.0),
                          child: Icon(Icons.close),
                        ),
                      ),
                    ),
                    AddSizeBox(20, 0),
                    AddText(StringUtils.THANKS_FOR_INSTALLING, Colors.black, 16,
                        FontWeight.normal, false),
                    AddSizeBox(70, 0),
                    AddText(StringUtils.WELCOME_SHAREAPP, Colors.black, 16,
                        FontWeight.normal, false),
                    AddSizeBox(30, 0),
                    AddText(StringUtils.INVITE_FRIENDS_, Colors.black, 16,
                        FontWeight.normal, false),
                    AddSizeBox(30, 0),
                    InkWell(
                      onTap: () {
                        setState(() {
                          isLoading = true;
                        });
                        sendTestSms();
                      },
                      child: AddText(StringUtils.SAMPLE_SMS_INVITE, Colors.blue,
                          16, FontWeight.normal, true),
                    ),
                    AddSizeBox(15, 0),
                    Visibility(
                      visible: false,
                      child: InkWell(
                        onTap: () {
                          setState(() {
                            isLoading = true;
                          });
                          sendTestEmail();
                        },
                        child: AddText(StringUtils.SAMPLE_EMAIL_INVITE,
                            Colors.blue, 16, FontWeight.normal, true),
                      ),
                    ),
                    AddSizeBox(30, 0),
                    AddText(StringUtils.TERMS_AND_CONDITION, Colors.black, 16,
                        FontWeight.normal, false),
                    InkWell(
                      onTap: () {
                        CommonUtils.openURL(StringUtils.LEARN_MORE_URL);
                      },
                      child: AddText(StringUtils.LEARN_MORE, Colors.blue, 16,
                          FontWeight.normal, true),
                    ),
                    AddSizeBox(30, 0),
                    //BottomButton(true),
                    BottomButton(false),
                  ],
                ),
              ),
              isLoading ? addProgress() : Container(),
            ],
          ),
        ),
      ),
    );
  }

  Future<void> requestPermission(Permission permission) async {
    final status = await permission.request();
    if (status == PermissionStatus.granted) {
      selectContact();
    }
  }

  void selectContact() async {
    Navigator.push(
        context,
        MaterialPageRoute(
            builder: (context) => ContactSelection(
                  title: StringUtils.CONTACT_SELECTION_TITLE,
                )));
  }

  Widget BottomButton(bool isEmail) {
    return InkWell(
      onTap: () {
        requestPermission(Permission.contacts);
      },
      child: Container(
        width: double.infinity,
        margin: isEmail
            ? EdgeInsets.all(10)
            : EdgeInsets.only(left: 10, right: 10, bottom: 10),
        color: Colors.black,
        child: Padding(
          padding: const EdgeInsets.all(15.0),
          child: AddText(
              isEmail
                  ? StringUtils.EMAIL_FRIENDS
                  : StringUtils.PHONE_BOOK_FRIENDS,
              Colors.white,
              18.0,
              FontWeight.bold,
              false),
        ),
      ),
    );
  }

  Future<void> sendTestSms() async {
    var body = json.encode({
      StringUtils.PHONE_NUMBER_PARAM: userBean.phone,
      StringUtils.TEMPLATE_ID: StringUtils.TEMPLATE_ID_VALUE
    });
    var p = await CommonUtils.apiCall(StringUtils.API_TEST_SMS, body);
    setState(() {
      isLoading = false;
    });
    CommonUtils.showToast(p[StringUtils.MESSAGE], Colors.green);
  }

  Future<void> sendTestEmail() async {
    var body = json.encode({
      StringUtils.EMAIL_PARAM: userBean.email,
      StringUtils.TEMPLATE_ID: StringUtils.TEMPLATE_ID_VALUE
    });
    var p = await CommonUtils.apiCall(StringUtils.API_TEST_EMAIL, body);
    setState(() {
      isLoading = false;
    });
    CommonUtils.showToast(p[StringUtils.MESSAGE], Colors.green);
  }
}
